@@ -5,9 +5,11 @@ from __future__ import annotations
 import logging
 import re
 import sys
+import sysconfig
 from abc import ABC, abstractmethod
+from dataclasses import dataclass
 from pathlib import Path
-from typing import TYPE_CHECKING, Any, List, NamedTuple, cast
+from typing import TYPE_CHECKING, Any, NamedTuple
 
 from virtualenv.discovery.py_spec import PythonSpec
 
@@ -26,13 +28,15 @@ class VersionInfo(NamedTuple):
     serial: int
 
 
-class PythonInfo(NamedTuple):
+@dataclass(frozen=True)
+class PythonInfo:
     implementation: str
     version_info: VersionInfo
     version: str
     is_64: bool
     platform: str
     extra: dict[str, Any]
+    free_threaded: bool = False
 
     @property
     def version_no_dot(self) -> str:
@@ -51,11 +55,14 @@ PY_FACTORS_RE = re.compile(
     r"""
     ^(?!py$)                                               # don't match 'py' as it doesn't provide any info
     (?P<impl>py|pypy|cpython|jython|graalpy|rustpython|ironpython) # the interpreter; most users will simply use 'py'
-    (?P<version>[2-9]\.?[0-9]?[0-9]?)?$                    # the version; one of: MAJORMINOR, MAJOR.MINOR
+    (?:
+    (?P<version>[2-9]\.?[0-9]?[0-9]?)                      # the version; one of: MAJORMINOR, MAJOR.MINOR
+    (?P<threaded>t?)                                       # version followed by t for free-threading
+    )?$
     """,
     re.VERBOSE,
 )
-PY_FACTORS_RE_EXPLICIT_VERSION = re.compile(r"^(?P<version>[2-9]\.[0-9]+)$")
+PY_FACTORS_RE_EXPLICIT_VERSION = re.compile(r"^((?P<impl>cpython|pypy)-)?(?P<version>[2-9]\.[0-9]+)(?P<threaded>t?)$")
 
 
 class Python(ToxEnv, ABC):
@@ -72,7 +79,7 @@ class Python(ToxEnv, ABC):
 
         self.conf.add_config(
             keys=["base_python", "basepython"],
-            of_type=List[str],
+            of_type=list[str],
             default=self.default_base_python,
             desc="environment identifier for python, first one found wins",
             post_process=validate_base_python,
@@ -100,6 +107,7 @@ class Python(ToxEnv, ABC):
         )
         self.conf.add_constant("py_dot_ver", "<python major>.<python minor>", value=self.py_dot_ver)
         self.conf.add_constant("py_impl", "python implementation", value=self.py_impl)
+        self.conf.add_constant("py_free_threaded", "is no-gil interpreted", value=self.py_free_threaded)
 
     def _default_set_env(self) -> dict[str, str]:
         env = super()._default_set_env()
@@ -111,6 +119,9 @@ class Python(ToxEnv, ABC):
     def py_dot_ver(self) -> str:
         return self.base_python.version_dot
 
+    def py_free_threaded(self) -> bool:
+        return self.base_python.free_threaded
+
     def py_impl(self) -> str:
         return self.base_python.impl_lower
 
@@ -120,6 +131,7 @@ class Python(ToxEnv, ABC):
             env.extend(
                 [
                     "APPDATA",  # Needed for PIP platformsdirs.windows
+                    "LOCALAPPDATA",  # Needed for pymanager
                     "PROGRAMDATA",  # needed for discovering the VS compiler
                     "PROGRAMFILES(x86)",  # needed for discovering the VS compiler
                     "PROGRAMFILES",  # needed for discovering the VS compiler
@@ -144,7 +156,8 @@ class Python(ToxEnv, ABC):
         candidates: list[str] = []
         match = PY_FACTORS_RE_EXPLICIT_VERSION.match(env_name)
         if match:
-            candidates.append(env_name)
+            found = match.groupdict()
+            candidates.append(f"{'pypy' if found['impl'] == 'pypy' else ''}{found['version']}{found['threaded']}")
         else:
             for factor in env_name.split("-"):
                 match = PY_FACTORS_RE.match(factor)
@@ -157,6 +170,15 @@ class Python(ToxEnv, ABC):
             return next(iter(candidates))
         return None
 
+    @classmethod
+    def _python_spec_for_sys_executable(cls) -> PythonSpec:
+        implementation = sys.implementation.name
+        version = sys.version_info
+        bits = "64" if sys.maxsize > 2**32 else "32"
+        threaded = "t" if sysconfig.get_config_var("Py_GIL_DISABLED") == 1 else ""
+        string_spec = f"{implementation}{version.major}{version.minor}{threaded}-{bits}"
+        return PythonSpec.from_string_spec(string_spec)
+
     @classmethod
     def _validate_base_python(
         cls,
@@ -172,13 +194,12 @@ class Python(ToxEnv, ABC):
                 if spec_base.path is not None:
                     path = Path(spec_base.path).absolute()
                     if str(spec_base.path) == sys.executable:
-                        ver, is_64 = sys.version_info, sys.maxsize != 2**32
-                        spec_base = PythonSpec.from_string_spec(f"{sys.implementation}{ver.major}{ver.minor}-{is_64}")
+                        spec_base = cls._python_spec_for_sys_executable()
                     else:
                         spec_base = cls.python_spec_for_path(path)
                 if any(
                     getattr(spec_base, key) != getattr(spec_name, key)
-                    for key in ("implementation", "major", "minor", "micro", "architecture")
+                    for key in ("implementation", "major", "minor", "micro", "architecture", "free_threaded")
                     if getattr(spec_name, key) is not None
                 ):
                     msg = f"env name {env_name} conflicting with base python {base_python}"
@@ -243,7 +264,7 @@ class Python(ToxEnv, ABC):
         changed = [f"{k}={old[k]!r}->{v!r}" for k, v in conf.items() if k in old and v != old[k]]
         if changed:
             result.append(f"changed {' | '.join(changed)}")
-        return f'python {", ".join(result)}'
+        return f"python {', '.join(result)}"
 
     @abstractmethod
     def prepend_env_var_path(self) -> list[Path]:
@@ -282,7 +303,7 @@ class Python(ToxEnv, ABC):
                 raise Skip(msg)
             raise NoInterpreter(base_pythons)
 
-        return cast(PythonInfo, self._base_python)
+        return self._base_python
 
     def _get_env_journal_python(self) -> dict[str, Any]:
         return {
@@ -292,6 +313,7 @@ class Python(ToxEnv, ABC):
             "is_64": self.base_python.is_64,
             "sysplatform": self.base_python.platform,
             "extra_version_info": None,
+            "free_threaded": self.base_python.free_threaded,
         }
 
     @abstractmethod
